package com.jqtx.windows.command;

import com.alibaba.fastjson.JSONObject;
import com.jqtx.windows.common.exception.BizException;
import com.jqtx.windows.common.factory.AbstractCommand;
import com.jqtx.windows.common.factory.RuntimeContextHolder;
import com.jqtx.windows.component.CreditComponent;
import com.jqtx.windows.component.model.CreditModel;
import com.jqtx.windows.component.model.GetSignContractModel;
import com.jqtx.windows.infrastructure.feign.IProtocalFeignService;
import com.jqtx.windows.web.request.SignContractRequest;
import com.jqtx.windows.web.response.JsonResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
@Slf4j
public class SignContractCommand extends AbstractCommand {

    @Autowired
    private IProtocalFeignService iProtocalFeignService;

    @Autowired
    private CreditComponent creditComponent;

    @Override
    public JsonResult execute() {
        String requestBody = RuntimeContextHolder.currentRuntimeContext().getRequestBody();
        SignContractRequest signContractRequest = JSONObject.parseObject(requestBody, SignContractRequest.class);
        try {
            CreditModel creditModel = creditComponent.getByOrderNo(signContractRequest.getOrderNo());
            signContractRequest.setClientName(creditModel.getClientName());
            signContractRequest.setCertNo(creditModel.getCertNo());
            signContractRequest.setClientCell(creditModel.getClientCell());
            log.info("融单协议提交-{}", JSONObject.toJSON(signContractRequest));
            creditModel.setCreditThirdToken("INIT");
            creditComponent.updateByOrderNo(creditModel.getOrderNo(), creditModel);
            iProtocalFeignService.uploadRongdan(signContractRequest);
        } catch (Exception e) {
            log.error("签约融单协议,授信编号:{},报错:{}", signContractRequest.getOrderNo(), e.getMessage(), e);
            throw new BizException("签约融单协议错误");
        }
        return JsonResult.success();
    }
}
